### v1.3.0

- Fixed a bug in GearIterator
- Implemented end_value for GearIterator so now it will behave as 
    range()

### v1.2.0

- Fixed Issue #2: .absolute() modifies the original value
- Implemented request #3: Renamed method .absolute() to __abs__

### v1.1.3

- Added CHANGELOG.md
- Tested with flake8, folowed most recommendations.
- Researched how to publish on conda-forge, prepared meta.yaml
    (will publish on conda in a future version)

### v1.1.2

- Stable version. Published on GitHub and PyPI.

